@@ -8,15 +8,11 @@ class KameleoonClientConfiguration:
 
     # pylint: disable=R0913
     def __init__(self,
-                 client_id: str = "",
-                 client_secret: str = "",
                  actions_configuration_refresh_interval: int = 60,
                  default_timeout: int = 2000,
                  visitor_data_maximum_size: int = 500,
                  environment: Optional[str] = None,
                  multi_threading: bool = False):
-        self.client_id = client_id
-        self.client_secret = client_secret
         self.actions_configuration_refresh_interval = actions_configuration_refresh_interval
         self.default_timeout = default_timeout
         self.visitor_data_maximum_size = visitor_data_maximum_size
