@@ -32,7 +32,7 @@ class ExperimentConfigurationNotFound(NotFoundError):
     is already deployed on the web-application's side)."""
 
     def __init__(self, message=None) -> None:
-        self.message = 'Experiment ' + str(message)
+        self.message = 'Experiment Id: ' + str(message)
         super().__init__(self.message)
 
 
@@ -51,7 +51,7 @@ class FeatureConfigurationNotFound(NotFoundError):
     has not yet been activated on Kameleoon's side."""
 
     def __init__(self, message=None) -> None:
-        self.message = 'Feature flag ' + str(message)
+        self.message = 'Feature flag Id: ' + str(message)
         super().__init__(self.message)
 
 
@@ -69,8 +69,9 @@ class NotTargeted(KameleoonException):
     did not trigger the required targeting conditions for this experiment.
     The targeting conditions are defined via Kameleoon's segment builder."""
 
-    def __init__(self, message=None) -> None:
-        self.message = "Visitor " + str(message) + " is not targeted."
+    def __init__(self, visitor_code=None, campaign_key_id=None) -> None:
+        self.message = "Visitor " + str(visitor_code) + \
+                       " is not targeted for " + str(campaign_key_id)
         super().__init__(self.message)
 
 
@@ -81,8 +82,9 @@ class NotActivated(KameleoonException):
     is that part of the traffic has been excluded from the
     experiment and should not be tracked."""
 
-    def __init__(self, message=None) -> None:
-        self.message = "Visitor " + str(message) + " is not activated."
+    def __init__(self, visitor_code=None, campaign_key_id=None) -> None:
+        self.message = "Visitor " + str(visitor_code) + \
+                       " is not activated for " + str(campaign_key_id)
         super().__init__(self.message)
 
 
