@@ -21,30 +21,9 @@ class Segment:
                 self.id = args[0]
                 self.tree = args[1]
 
-    def check_tree(self, targeting_data) -> Optional[bool]:
+    def check_tree(self, get_targeting_data) -> Optional[bool]:
         if not self.tree:
             is_targeted: Optional[bool] = True
         else:
-            is_targeted = self.tree.check(targeting_data)
-        return is_targeted is True
-
-
-ConditionType = {
-    "CUSTOM_DATUM": "CUSTOM_DATUM"
-}
-
-DataType = {
-    "CUSTOM": "CUSTOM"
-}
-
-Operator = {
-    "UNDEFINED": "UNDEFINED",
-    "CONTAINS": "CONTAINS",
-    "EXACT": "EXACT",
-    "MATCH": "REGULAR_EXPRESSION",
-    "LOWER": "LOWER",
-    "EQUAL": "EQUAL",
-    "GREATER": "GREATER",
-    "IS_TRUE": "TRUE",
-    "IS_FALSE": "FALSE"
-}
+            is_targeted = self.tree.check(get_targeting_data)
+        return is_targeted is True
\ No newline at end of file
